@@ -3,7 +3,8 @@ testthat::context("Evaluate")
 testthat::test_that("", {
   e <- new.env(parent = environment())
   fname <- system.file("Introduction.Rmd", package = "REPLesentR")
-  slideDeck <- SlideDeck()$new(Read()$auto(fname, quiet = TRUE))
+  file.copy(fname, tfname <- tempfile(fileext = ".Rmd"))
+  slideDeck <- SlideDeck()$new(Read()$auto(tfname, quiet = TRUE))
   evaluate <- Evaluate(e, quiet = TRUE)
   evaluate$slideDeck(slideDeck)
   l <- as.list(e, all.names = TRUE)
