@@ -2,7 +2,8 @@ testthat::context("SlideDeck")
 
 testthat::test_that("Testing the introduction presentation", {
   fname <- system.file("Introduction.Rmd", package = "REPLesentR", mustWork = TRUE)
-  rawText <- Read()$auto(fname, quiet = TRUE)
+  file.copy(fname, tfname <- tempfile(fileext = ".Rmd"))
+  rawText <- Read()$auto(tfname, quiet = TRUE)
   slideDeck <- SlideDeck()$new(rawText)
   testthat::expect_true(length(slideDeck) == 10)
   lapply(slideDeck, function(slide) {
